/*
 * gtk GUI functions
 *
 * This file is part of ANT (Ant is Not a Telephone)
 *
 * Copyright 2002 Roland Stigge
 *
 */

/* own header files */
#include "session.h"

GtkWidget *ok_dialog_get(char *title, char *contents,
			 GtkJustification justification);
void show_audio_error_dialog();
int main_gtk(struct session_t *session);
